#!/bin/bash
#
# source: http://downloads.sourceforge.net/project/scribus/scribus-devel/1.3.5.1/scribus-1.3.5.1.tar.bz2
#
# maintainer: (scribus, seek a maintainer)
#
#

# Set initial variables:

soft='scribus'
softversion='1.3.5.1'
packageversion='62.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest

cd $src
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

cmake \
    -DCMAKE_BUILD_TYPE=Release \
    -DCMAKE_INSTALL_PREFIX=/usr \
    
make -j4
make install DESTDIR=$dest

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

mkdir $dest/usr/share/applications
cp $src/scribus.desktop $dest/usr/share/applications

mkdir -p $dest/usr/share/icons/hicolor/scalable/apps
cp $buildir/scribus.svg $dest/usr/share/icons/hicolor/scalable/apps

# Compress and link manpages, if any:
mv $dest/usr/share/man $dest/usr
if [ -d $dest/usr/man ]; then
  ( cd $dest/usr/man
    for manpagedir in $(find . -type d -name "man*") ; do
      ( cd $manpagedir
        for eachpage in $( find . -type l -maxdepth 1) ; do
          ln -s $( readlink $eachpage ).gz $eachpage.gz
          rm $eachpage
        done
        gzip -9 *.?
      )
    done
  )
fi

mkdir -p $dest/usr/doc/
mv  $dest/usr/share/doc/$soft-$softversion $dest/usr/doc/
rm $dest/usr/doc/$soft-$softversion/ChangeLogSVN

mkdir -p $dest/install

cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

       |-----handy-ruler------------------------------------------------------|
scribus: scribus - Open-source Desktop Publishing
scribus:
scribus: Scribus is an open-source program that brings award-winning
scribus: professional page layout to Linux/Unix desktops with a combination
scribus: of 'press-ready' output and new approaches to page layout
scribus: 
scribus: 
scribus: 
scribus:
scribus:
scribus:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging
cd $dest
makepkg -l y -c n $dest.txz
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.txz > $package.md5
